==> TConstruct-1.19.2-3.8.5.59-sources.jar: slimeknights/tconstruct/library/client/data/AbstractArmorModelProvider.java <==
package slimeknights.tconstruct.library.client.data;

import net.minecraft.data.CachedOutput;
import net.minecraft.data.DataGenerator;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.server.packs.PackType;
import slimeknights.mantle.data.GenericDataProvider;
import slimeknights.mantle.registration.object.IdAwareObject;
import slimeknights.tconstruct.library.client.armor.ArmorModelManager;
import slimeknights.tconstruct.library.client.armor.ArmorModelManager.ArmorModel;
import slimeknights.tconstruct.library.client.armor.texture.ArmorTextureSupplier;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;

/** Data provider for armor models */
public abstract class AbstractArmorModelProvider extends GenericDataProvider {
  private final Map<ResourceLocation,ArmorModel> models = new HashMap<>();

  public AbstractArmorModelProvider(DataGenerator generator) {
    super(generator, PackType.CLIENT_RESOURCES, ArmorModelManager.FOLDER);
  }

  /** Add all models to the manager */
  protected abstract void addModels();

  @Override
  public void run(CachedOutput output) throws IOException {
    addModels();
    models.forEach((id, model) -> saveJson(output, id, ArmorModel.LOADABLE.serialize(model)));
  }

  /** Adds a model to the generator */
  protected void addModel(ResourceLocation name, ArmorTextureSupplier... layers) {
    ArmorModel existing = this.models.putIfAbsent(name, new ArmorModel(List.of(layers)));
    if (existing != null) {
      throw new IllegalArgumentException("Duplicate armor model at " + name + ", previous value " + existing);
    }
  }

  /** Adds a model to the generator */
  protected void addModel(IdAwareObject name, ArmorTextureSupplier... layers) {
    addModel(name.getId(), layers);
  }

  /** Adds a model to the generator */
  protected void addModel(IdAwareObject name, Function<ResourceLocation,ArmorTextureSupplier[]> layers) {
    addModel(name.getId(), layers.apply(name.getId()));
  }
}

==> TConstruct-1.20.1-3.11.2.183-sources.jar: slimeknights/tconstruct/library/client/data/AbstractArmorModelProvider.java <==
package slimeknights.tconstruct.library.client.data;

import net.minecraft.data.CachedOutput;
import net.minecraft.data.PackOutput;
import net.minecraft.data.PackOutput.Target;
import net.minecraft.resources.ResourceLocation;
import slimeknights.mantle.data.GenericDataProvider;
import slimeknights.mantle.registration.object.IdAwareObject;
import slimeknights.tconstruct.library.client.armor.ArmorModelManager;
import slimeknights.tconstruct.library.client.armor.ArmorModelManager.ArmorModel;
import slimeknights.tconstruct.library.client.armor.texture.ArmorTextureSupplier;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CompletableFuture;
import java.util.function.Function;

/** Data provider for armor models */
public abstract class AbstractArmorModelProvider extends GenericDataProvider {
  private final Map<ResourceLocation,ArmorModel> models = new HashMap<>();

  public AbstractArmorModelProvider(PackOutput packOutput) {
    super(packOutput, Target.RESOURCE_PACK, ArmorModelManager.FOLDER);
  }

  /** Add all models to the manager */
  protected abstract void addModels();

  @Override
  public CompletableFuture<?> run(CachedOutput output) {
    addModels();
    return allOf(models.entrySet().stream().map(entry -> saveJson(output, entry.getKey(), ArmorModel.LOADABLE.serialize(entry.getValue()))));
  }

  /** Adds a model to the generator */
  protected void addModel(ResourceLocation name, ArmorTextureSupplier... layers) {
    ArmorModel existing = this.models.putIfAbsent(name, new ArmorModel(List.of(layers)));
    if (existing != null) {
      throw new IllegalArgumentException("Duplicate armor model at " + name + ", previous value " + existing);
    }
  }

  /** Adds a model to the generator */
  protected void addModel(IdAwareObject name, ArmorTextureSupplier... layers) {
    addModel(name.getId(), layers);
  }

  /** Adds a model to the generator */
  protected void addModel(IdAwareObject name, Function<ResourceLocation,ArmorTextureSupplier[]> layers) {
    addModel(name.getId(), layers.apply(name.getId()));
  }
}
